FileDesc

Struct FileDesc 

pub struct FileDesc(OwnedFd);
🔬This is a nightly-only experimental API. (fd)

Tuple Fields

0: OwnedFd
🔬This is a nightly-only experimental API. (fd)

Implementations

Source

impl FileDesc

pub fn try_clone(&self) -> Result<Self>

🔬This is a nightly-only experimental API. (fd)
pub fn read(&self, buf: &mut [u8]) -> Result<usize>

🔬This is a nightly-only experimental API. (fd)
pub fn read_vectored(&self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize>

🔬This is a nightly-only experimental API. (fd)
Available on neither ESP-IDF nor Horizon nor Play Station Vita nor NuttX.
pub fn is_read_vectored(&self) -> bool

🔬This is a nightly-only experimental API. (fd)
pub fn read_to_end(&self, buf: &mut Vec<u8>) -> Result<usize>

🔬This is a nightly-only experimental API. (fd)
pub fn read_at(&self, buf: &mut [u8], offset: u64) -> Result<usize>

🔬This is a nightly-only experimental API. (fd)
pub fn read_buf(&self, cursor: BorrowedCursor<'_>) -> Result<()>

🔬This is a nightly-only experimental API. (fd)
pub fn read_buf_at(&self, cursor: BorrowedCursor<'_>, offset: u64) -> Result<()>

🔬This is a nightly-only experimental API. (fd)
pub fn read_vectored_at( &self, bufs: &mut [IoSliceMut<'_>], offset: u64, ) -> Result<usize>

🔬This is a nightly-only experimental API. (fd)
Available on AIX or DragonFly BSD or Emscripten or FreeBSD or Fuchsia or GNU/Hurd or illumos or Linux or NetBSD or OpenBSD only.
pub fn write(&self, buf: &[u8]) -> Result<usize>

🔬This is a nightly-only experimental API. (fd)
pub fn write_vectored(&self, bufs: &[IoSlice<'_>]) -> Result<usize>

🔬This is a nightly-only experimental API. (fd)
Available on neither ESP-IDF nor Horizon nor Play Station Vita nor NuttX.
pub fn is_write_vectored(&self) -> bool

🔬This is a nightly-only experimental API. (fd)
pub fn write_at(&self, buf: &[u8], offset: u64) -> Result<usize>

🔬This is a nightly-only experimental API. (fd)
pub fn write_vectored_at( &self, bufs: &[IoSlice<'_>], offset: u64, ) -> Result<usize>

🔬This is a nightly-only experimental API. (fd)
Available on AIX or DragonFly BSD or Emscripten or FreeBSD or Fuchsia or GNU/Hurd or illumos or Linux or NetBSD or OpenBSD only.
pub fn set_cloexec(&self) -> Result<()>

🔬This is a nightly-only experimental API. (fd)
Available on Newlib and neither ESP-IDF nor Horizon nor Play Station Vita, or Solaris, or illumos, or Emscripten, or Fuchsia, or L4Re, or Linux, or Cygwin, or Haiku, or Redox OS, or VxWorks, or QNX Neutrino, or WASI only.
pub fn set_nonblocking(&self, nonblocking: bool) -> Result<()>

🔬This is a nightly-only experimental API. (fd)
Available on Linux only.
pub fn duplicate(&self) -> Result<FileDesc>

🔬This is a nightly-only experimental API. (fd)